from .plan_and_research import PLAN_AND_RESEARCH_PROMPT, BUILDER_CORE_PROMPT
from .copilot import BASE_AGENT_PROMPT
from .web_researcher import WEB_RESEARCHER_SYSTEM_PROMPT
from .skill_builder import SKILL_BUILDER_SYSTEM_PROMPT_TEMPLATE
from .toolkit_builder import TOOLKIT_BUILDER_SYSTEM_PROMPT_TEMPLATE
from .subagent_builder import SUBAGENT_BUILDER_SYSTEM_PROMPT_TEMPLATE
from .trainer_agent import TRAINER_AGENT_SYSTEM_PROMPT_TEMPLATE

__all__ = [
    "PLAN_AND_RESEARCH_PROMPT",
    "BUILDER_CORE_PROMPT",
    "BASE_AGENT_PROMPT",
    "WEB_RESEARCHER_SYSTEM_PROMPT",
    "SKILL_BUILDER_SYSTEM_PROMPT_TEMPLATE",
    "TOOLKIT_BUILDER_SYSTEM_PROMPT_TEMPLATE",
    "SUBAGENT_BUILDER_SYSTEM_PROMPT_TEMPLATE",
    "TRAINER_AGENT_SYSTEM_PROMPT_TEMPLATE",
]
